Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1499)

Unified Diff: content/test/test_content_client.cc

Issue 456413002: Move the user agent styles sheets to blink_resources.grd (Part 2) with Unit test support (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Patch after rebased! Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/test/blink_test_environment.cc ('k') | content/test/test_webkit_platform_support.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/test/test_content_client.cc
diff --git a/content/test/test_content_client.cc b/content/test/test_content_client.cc
index abd1aeadf7bfcae0f69ff5158750ef15c21ec8b6..0ccc8cf5838c07d5861a0d8ff39181ee71571b18 100644
--- a/content/test/test_content_client.cc
+++ b/content/test/test_content_client.cc
@@ -14,20 +14,20 @@ namespace content {
TestContentClient::TestContentClient()
: data_pack_(ui::SCALE_FACTOR_100P) {
// content_resources.pak is not built on iOS as it is not required.
#if !defined(OS_IOS)
- base::FilePath content_resources_pack_path;
+ base::FilePath content_shell_pack_path;
#if defined(OS_ANDROID)
// on Android all pak files are inside the paks folder.
- PathService::Get(base::DIR_ANDROID_APP_DATA, &content_resources_pack_path);
- content_resources_pack_path = content_resources_pack_path.Append(
+ PathService::Get(base::DIR_ANDROID_APP_DATA, &content_shell_pack_path);
+ content_shell_pack_path = content_shell_pack_path.Append(
FILE_PATH_LITERAL("paks"));
#else
- PathService::Get(base::DIR_MODULE, &content_resources_pack_path);
+ PathService::Get(base::DIR_MODULE, &content_shell_pack_path);
#endif
- content_resources_pack_path = content_resources_pack_path.Append(
- FILE_PATH_LITERAL("content_resources.pak"));
- data_pack_.LoadFromPath(content_resources_pack_path);
+ content_shell_pack_path = content_shell_pack_path.Append(
+ FILE_PATH_LITERAL("content_shell.pak"));
+ data_pack_.LoadFromPath(content_shell_pack_path);
#endif
}
« no previous file with comments | « content/test/blink_test_environment.cc ('k') | content/test/test_webkit_platform_support.cc » ('j') | no next file with comments »
@@ -14,20 +14,20 @@ namespace content {
TestContentClient::TestContentClient()
: data_pack_(ui::SCALE_FACTOR_100P) {
- // content_resources.pak is not built on iOS as it is not required.
+ // content_shell.pak is not built on iOS as it is not required.
#if !defined(OS_IOS)

Powered by Google App Engine
This is Rietveld 408576698